==> parley_16.08.3.orig.tar.xz: parley-16.08.3/src/statistics/lessonstatisticsview.h <==
/***************************************************************************

    Copyright 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LESSONSTATISTICSVIEW_H
#define LESSONSTATISTICSVIEW_H

#include "containerview.h"

/**
 * View for the lesson list.
 * @author Frederik Gladhorn <frederik.gladhorn@kdemail.net>
 */
class LessonStatisticsView : public ContainerView
{
    Q_OBJECT

public:
    LessonStatisticsView(QWidget *parent);
    void setModel(ContainerModel *model);

private Q_SLOTS:
    void removeGrades();
    void removeGradesChildren();

protected:
    virtual void resizeEvent(QResizeEvent *event);

private Q_SLOTS:
    void sectionResized(int index, int /*oldSize*/, int /*newSize*/);
    void adjustColumnWidths();

private:
    virtual void setModel(QAbstractItemModel *model) {
        Q_UNUSED(model)
    }
};

#endif

==> parley_17.12.3.orig.tar.xz: parley-17.12.3/src/statistics/lessonstatisticsview.h <==
/***************************************************************************

    Copyright 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LESSONSTATISTICSVIEW_H
#define LESSONSTATISTICSVIEW_H

#include "containerview.h"

/**
 * View for the lesson list.
 * @author Frederik Gladhorn <frederik.gladhorn@kdemail.net>
 */
class LessonStatisticsView : public ContainerView
{
    Q_OBJECT

public:
    LessonStatisticsView(QWidget *parent);
    void setModel(ContainerModel *model) Q_DECL_OVERRIDE;

private Q_SLOTS:
    void removeGrades();
    void removeGradesChildren();

protected:
    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;

private Q_SLOTS:
    void sectionResized(int index, int /*oldSize*/, int /*newSize*/);
    void adjustColumnWidths();

private:
    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE {
        Q_UNUSED(model)
    }
};

#endif
